@@ -1,4 +1,6 @@
 package MIME::Decoder::QuotedPrint;
+use strict;
+use warnings;
 
 
 =head1 NAME
@@ -56,7 +58,7 @@ use MIME::QuotedPrint;
 @ISA = qw(MIME::Decoder);
 
 # The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = "5.501";
+$VERSION = "5.508";
 
 #------------------------------
 # If we have MIME::QuotedPrint 3.03 or later, use the three-argument
